@@ -28,7 +28,9 @@ module VCR
         # @return [String] the YAML string
         def serialize(hash)
           handle_encoding_errors do
-            ::Psych.dump(hash)
+            result = ::Psych.dump(hash)
+            result.gsub!(": \n", ": null\n") # set canonical null value in order to avoid trailing whitespaces
+            result
           end
         end
 
